@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/bash -e
 
 VERSION="$1" # E.g: '42.3'
 
@@ -10,7 +10,7 @@ else
   NAME="opensuse32/leap"
 fi
 
-IMAGE="${NAME}:${VERSION}"
+IMAGE="${NAME}:latest"
 INSTALLROOT="/dev/shm/${IMAGE}"
 
 sudo rm -rf "${INSTALLROOT}"
@@ -27,13 +27,30 @@ if [ "${VERSION}" != "tumbleweed" ]; then
   sudo zypper --root "${INSTALLROOT}" \
     ar "http://download.opensuse.org/update/leap/${VERSION}/non-oss/" "update-non-oss"
 fi
-setarch i686 sudo zypper --root "${INSTALLROOT}" \
+sudo zypper --root "${INSTALLROOT}" \
   --gpg-auto-import-keys ref
-setarch i686 sudo zypper --root "${INSTALLROOT}" \
-  install -y bash vim zypper openSUSE-release
+sudo setarch i686 zypper --root "${INSTALLROOT}"  \
+  install --download-only -y \
+  bash \
+  filesystem \
+  glibc \
+  glibc-extra \
+  libpcre1 \
+  libselinux1 \
+  openSUSE-release \
+  system-user-root \
+  util-linux vim \
+  zypper
+sudo rpm -Uvh --root "${INSTALLROOT}" "${INSTALLROOT}/var/cache/zypp/packages/oss/"*"/"*".rpm"
 
-sudo tar -C "${INSTALLROOT}" -c . >"${IMAGE}.tar"
+sudo chroot "${INSTALLROOT}" rpmdb --rebuilddb
+
+FILE="${IMAGE//\//_}.tar"
+sudo tar -C "${INSTALLROOT}" -c . >"${FILE}"
 sudo rm -rf "${INSTALLROOT}"
 
 docker rmi -f "${IMAGE}"
-docker import "${IMAGE}.tar" "${IMAGE}"
+docker import "${FILE}" "${IMAGE}"
+
+pigz "${FILE}"
+mv -fv "${FILE}.gz" "${HOME}/tde/docker"
